==> open-xchange-guard_2.6.0.orig.tar.bz2: open-xchange-guard-2.6.0/com.openexchange.guard.guestreset/src/com/openexchange/guard/guestreset/exceptions/GuardGuestResetExceptionCodes.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.guard.guestreset.exceptions;

import com.openexchange.exception.Category;
import com.openexchange.exception.DisplayableOXExceptionCode;
import com.openexchange.exception.OXException;
import com.openexchange.exception.OXExceptionFactory;
import com.openexchange.exception.OXExceptionStrings;

public enum GuardGuestResetExceptionCodes implements DisplayableOXExceptionCode {

    /** Unable to find guest account for email %1$s'. */
    UNKNOWN_GUEST_ACCOUNT("Unable to find guest account for email '%1$s'.", GuestResetExceptionMessages.UNABLE_TO_FIND, CATEGORY_ERROR, 1),

    /** Unable to reset user with email '%1$s'. */
    UNABLE_TO_RESET("Unable to reset user with email '%1$s'.", CATEGORY_ERROR, 2),

    RECOVERY_EXISTS("Recovery exists for the user %1$s'.", CATEGORY_ERROR, 3),

    TOKEN_RETIEVAL_ERROR("Error retrieving token, %1$s'.", CATEGORY_ERROR, 4),

    TOKEN_SAVE_ERROR ("Error saving token %1$s'.", CATEGORY_ERROR, 5),

    LOCKOUT("Temporary Lockout", CATEGORY_ERROR, 6),

    BAD_TOKEN("Bad token %1$s'.", CATEGORY_ERROR, 7),

    BAD_EMAIL_ADDRESS("Bad email address %1$s'.", CATEGORY_ERROR, 8),

    MIN_PASSWORD_LENGTH("Password must be at least %1$s characters", GuestResetExceptionMessages.MIN_PASSWORD_LENGTH, CATEGORY_ERROR, 9),

    SQL_ERROR ("SQL Error with temporary token %1$s'.", CATEGORY_ERROR, 10),

    ;

    private final String message;
    private final String displayMessage;
    private final Category category;
    private final int number;

    private GuardGuestResetExceptionCodes(String message, Category category, int number) {
        this(message, null, category, number);
    }

    private GuardGuestResetExceptionCodes(String message, String displayMessage, Category category, int number) {
        this.message = message;
        this.displayMessage = displayMessage != null ? displayMessage : OXExceptionStrings.MESSAGE;
        this.category = category;
        this.number = number;
    }

    @Override
    public String getPrefix() {
        return "GRD-GUEST-RESET";
    }

    @Override
    public int getNumber() {
        return number;
    }

    @Override
    public String getMessage() {
        return message;
    }

    @Override
    public String getDisplayMessage() {
        return displayMessage;
    }

    @Override
    public Category getCategory() {
        return category;
    }

    @Override
    public boolean equals(OXException e) {
        return OXExceptionFactory.getInstance().equals(this, e);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @return The newly created {@link OXException} instance
     */
    public OXException create() {
        return OXExceptionFactory.getInstance().create(this, new Object[0]);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @param args The message arguments in case of printf-style message
     * @return The newly created {@link OXException} instance
     */
    public OXException create(Object... args) {
        return OXExceptionFactory.getInstance().create(this, (Throwable) null, args);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @param cause The optional initial cause
     * @param args The message arguments in case of printf-style message
     * @return The newly created {@link OXException} instance
     */
    public OXException create(Throwable cause, Object... args) {
        return OXExceptionFactory.getInstance().create(this, cause, args);
    }

}

==> open-xchange-guard_2.10.1.orig.tar.bz2: open-xchange-guard-2.10.1/com.openexchange.guard.guestreset/src/com/openexchange/guard/guestreset/exceptions/GuardGuestResetExceptionCodes.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.guard.guestreset.exceptions;

import com.openexchange.exception.Category;
import com.openexchange.exception.DisplayableOXExceptionCode;
import com.openexchange.exception.OXException;
import com.openexchange.exception.OXExceptionFactory;
import com.openexchange.exception.OXExceptionStrings;

public enum GuardGuestResetExceptionCodes implements DisplayableOXExceptionCode {

    /** Unable to find guest account for email %1$s'. */
    UNKNOWN_GUEST_ACCOUNT("Unable to find guest account for email '%1$s'.", GuestResetExceptionMessages.UNKNOWN_GUEST_ACCOUNT_MSG, CATEGORY_ERROR, 1),

    /** Unable to reset user with email '%1$s'. */
    UNABLE_TO_RESET("Unable to reset user with email '%1$s'.", GuestResetExceptionMessages.UNABLE_TO_RESET_MSG, CATEGORY_ERROR, 2),

    RECOVERY_EXISTS("Recovery exists for the user %1$s'.", GuestResetExceptionMessages.RECOVERY_EXISTS_MSG, CATEGORY_ERROR, 3),

    TOKEN_RETIEVAL_ERROR("Error retrieving token: %1$s'.", GuestResetExceptionMessages.TOKEN_RETIEVAL_ERROR_MSG, CATEGORY_ERROR, 4),

    TOKEN_SAVE_ERROR ("Error saving token %1$s'.", GuestResetExceptionMessages.TOKEN_SAVE_ERROR_MSG, CATEGORY_ERROR, 5),

    BAD_TOKEN("Bad token %1$s'.", GuestResetExceptionMessages.BAD_TOKEN_MSG, CATEGORY_ERROR, 7),

    BAD_EMAIL_ADDRESS("Bad email address %1$s'.", GuestResetExceptionMessages.BAD_EMAIL_ADDRESS_MSG, CATEGORY_ERROR, 8),

    MIN_PASSWORD_LENGTH("Password must be at least %1$s characters", GuestResetExceptionMessages.MIN_PASSWORD_LENGTH_MSG, CATEGORY_ERROR, 9),

    ;

    private final String message;
    private final String displayMessage;
    private final Category category;
    private final int number;

    private GuardGuestResetExceptionCodes(String message, Category category, int number) {
        this(message, null, category, number);
    }

    private GuardGuestResetExceptionCodes(String message, String displayMessage, Category category, int number) {
        this.message = message;
        this.displayMessage = displayMessage != null ? displayMessage : OXExceptionStrings.MESSAGE;
        this.category = category;
        this.number = number;
    }

    @Override
    public String getPrefix() {
        return "GRD-GUEST-RESET";
    }

    @Override
    public int getNumber() {
        return number;
    }

    @Override
    public String getMessage() {
        return message;
    }

    @Override
    public String getDisplayMessage() {
        return displayMessage;
    }

    @Override
    public Category getCategory() {
        return category;
    }

    @Override
    public boolean equals(OXException e) {
        return OXExceptionFactory.getInstance().equals(this, e);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @return The newly created {@link OXException} instance
     */
    public OXException create() {
        return OXExceptionFactory.getInstance().create(this, new Object[0]);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @param args The message arguments in case of printf-style message
     * @return The newly created {@link OXException} instance
     */
    public OXException create(Object... args) {
        return OXExceptionFactory.getInstance().create(this, (Throwable) null, args);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @param cause The optional initial cause
     * @param args The message arguments in case of printf-style message
     * @return The newly created {@link OXException} instance
     */
    public OXException create(Throwable cause, Object... args) {
        return OXExceptionFactory.getInstance().create(this, cause, args);
    }

}
